@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function
+from typing import Any, Dict
 
 from vivarium.core.process import Deriver
 
@@ -6,7 +6,7 @@ from vivarium.core.process import Deriver
 class AgentNames(Deriver):
 
     name = 'agent_names'
-    defaults = {}
+    defaults: Dict[str, Any] = {}
 
     def __init__(self, initial_parameters=None):
         if initial_parameters is None:
